pub struct CertificateLookupArguments {
lookup: CertificateLookup,
}Fields
lookup: CertificateLookupTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CertificateLookupArguments
Manual, not derived: exactly one of the two arguments has to be given, which
#[derive(Deserialize)] can’t express, and this is what ChatbotTool::Arguments’s
DeserializeOwned bound is satisfied by (parse_arguments below is overridden and never
calls it, but the bound still has to hold).
impl<'de> Deserialize<'de> for CertificateLookupArguments
Manual, not derived: exactly one of the two arguments has to be given, which
#[derive(Deserialize)] can’t express, and this is what ChatbotTool::Arguments’s
DeserializeOwned bound is satisfied by (parse_arguments below is overridden and never
calls it, but the bound still has to hold).
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more